@@ -4,7 +4,7 @@ toolchest_client.tools.python3
 
 This is the Python3 implementation of the Tool class.
 """
-from toolchest_client.files import OutputType
+from toolchest_client.files import OutputType, path_is_s3_uri
 
 from . import Tool
 
@@ -20,6 +20,6 @@ class Python3(Tool):
             tool_args=tool_args,
             output_path=output_path,
             inputs=inputs,
-            output_type=OutputType.GZ_TAR,
+            output_type=OutputType.S3 if path_is_s3_uri(output_path) else OutputType.GZ_TAR,
             **kwargs,
         )
